"""
Author: Michel Peltriaux
Organization: Struktur- und Genehmigungsdirektion Nord, Rhineland-Palatinate, Germany
Contact: ksp-servicestelle@sgdnord.rlp.de
Created on: 19.08.22

"""
from django.contrib.auth.decorators import login_required
from django.http import HttpRequest
from django.shortcuts import get_object_or_404
from django.urls import reverse
from django.utils.translation import gettext_lazy as _

from compensation.models import EcoAccount
from konova.decorators import shared_access_required, default_group_required
from konova.forms.modals import ResubmissionModalForm


@login_required
@default_group_required
@shared_access_required(EcoAccount, "id")
def create_resubmission_view(request: HttpRequest, id: str):
    """ Renders resubmission form for an eco account

    Args:
        request (HttpRequest): The incoming request
        id (str): EcoAccount's id

    Returns:

    """
    acc = get_object_or_404(EcoAccount, id=id)
    form = ResubmissionModalForm(request.POST or None, instance=acc, request=request)
    form.action_url = reverse("compensation:acc:resubmission-create", args=(id,))
    return form.process_request(
        request,
        msg_success=_("Resubmission set"),
        redirect_url=reverse("compensation:acc:detail", args=(id,))
    )
